@@ -169,10 +169,25 @@ class CBConnect(CBSession):
                 collection_spec = CollectionSpec(name, scope_name=self._scope.name)
                 cm = self._bucket.collections()
                 cm.create_collection(collection_spec, CreateCollectionOptions(timeout=timedelta(seconds=25)))
+                retry_inline(self.get_collection, cm, name)
         except CollectionAlreadyExistsException:
             pass
         return self.collection(name)
 
+    @staticmethod
+    def get_scope(cm, scope_name):
+        return next((s for s in cm.get_all_scopes() if s.name == scope_name), None)
+
+    def get_collection(self, cm, collection_name):
+        collection = None
+        scope = self.get_scope(cm, self._scope.name)
+        if scope:
+            collection = next((c for c in scope.collections if c.name == collection_name), None)
+        if not collection:
+            raise CollectionNameNotFound(f"collection {collection_name} not found")
+        else:
+            return collection
+
     @retry()
     def drop_collection(self, name):
         self.logger.debug(f"drop_collection: drop collection {name}")
